@@ -48,10 +48,7 @@
 #include <string.h>
 #endif
 
-#include <openssl/ssl.h>
-#include <openssl/err.h>
-#include "libclamav/crypto.h"
-
+#include "clamav.h"
 #include "cltypes.h"
 #include "pe.h"
 #include "others.h"
